@@ -142,6 +142,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_lambda
@@ -164,14 +166,14 @@ class SqsToLambda(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        sqs_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -189,6 +191,10 @@ class SqsToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the SqsToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SqsToLambdaProps(
             dead_letter_queue_props=dead_letter_queue_props,
             deploy_dead_letter_queue=deploy_dead_letter_queue,
@@ -236,14 +242,14 @@ class SqsToLambdaProps:
     def __init__(
         self,
         *,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        sqs_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
@@ -265,6 +271,16 @@ class SqsToLambdaProps:
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(sqs_event_source_props, dict):
             sqs_event_source_props = aws_cdk.aws_lambda_event_sources.SqsEventSourceProps(**sqs_event_source_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsToLambdaProps.__init__)
+            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
+            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
+            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
+            check_type(argname="argument sqs_event_source_props", value=sqs_event_source_props, expected_type=type_hints["sqs_event_source_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
